import os

def initsetup():

    if os.path.isdir('www') == True:

        print('Folder www already exits. please delete first www folder and manage.py file.')

    else:
        cmd = 'django-admin startproject www .'
        print('creating a server .............')
        os.system(cmd)
        print('please wait...')

        createfile = 'VirtualHost.py'
        get_content = "virtual_hosts = {" \
                      "\n   'test.com:8000': 'www.urls'," \
                      "\n   'example.com:8000': 'ex.urls'," \
                      "\n}"

        print('we are creating files...')
        f = open(createfile, "w")
        print(f)
        f.write(get_content)
        f.close()

        word = 'INSTALLED_APPS'
        middletext = 'MIDDLEWARE = ['
        hostallow = 'ALLOWED_HOSTS = []'
        ROOT_Url = "ROOT_URLCONF = 'www.urls'"

        with open('www/settings.py', 'r') as fp:
            # read all lines in a list
            lines = fp.readlines()
            count = 0
            f = open('www/settings.py', 'w')

            for line in lines:
                # check if string present on a current line
                if line.find(word) != -1:
                    count += 1
                    print('Installing Module in to', word)
                    x = lines.index(line) + count
                    print('Finding the Line Number:', x)
                    print('Inserting bigsansar module in to', line)

                    code = "    'bigsansar.apps.BigsansarConfig'," \
                           "\n" \
                           "    'bigsansar.contrib.account.apps.AccountConfig'," \
                           "\n" \
                           "    'bigsansar.contrib.sites.apps.SitesConfig'," \
                           "\n"

                    lines.insert(x, code)

                elif line.find(middletext) != -1:

                    print('Reading the lines', middletext)
                    xy = lines.index(line) + 1
                    print('Finding the Line Number:', xy)
                    print('Inserting bigsansar virtualhost middleware  in to', line)

                    middlecode = "    'bigsansar.core.host.VirtualHostMiddleware'," \
                                 "\n"
                    lines.insert(xy, middlecode)

                elif line.find(hostallow) != -1:
                    xyz = lines.index(line)

                    # delete lines
                    del lines[xyz]

                    hostcode = "ALLOWED_HOSTS = ['*']" \
                               "\n" \
                               "\n" \
                               "# this is only for development mode" \
                               "\n" \
                               "EMAIL_BACKEND = 'django.core.mail.backends.console.EmailBackend'" \
                               "\n" \
                               "\n" \
                               "ROOT_URLCONF = 'bigsansar.urls'" \
                               "\n"

                    lines.insert(xyz, hostcode)

                elif line.find(ROOT_Url) != -1:
                    rooturlindex = lines.index(line)

                    #delete lines
                    del lines[rooturlindex]

            contents = "".join(lines)
            f.write(contents)
            f.close()

        # Open a file with access mode 'a'
        with open("www/urls.py", "a") as file_object:
            # Append 'hello' at the end of file
            file_object.write(''
                              '\n'
                              'admin.site.site_header = "BIGSANSAR"'
                              '\n'
                              'admin.site.site_title = "Bigsansar"'
                              '\n'
                              'admin.site.index_title = "This is a admin panel"'
                              '\n')
            # Close the file
            file_object.close()

        migrate = 'python manage.py migrate'
        os.system(migrate)

        print('Finished')



import datetime
from django.contrib.sites.shortcuts import get_current_site
from django.http import HttpResponse
from django.shortcuts import render
from django.template import loader

from bigsansar.contrib.sites.models import domains

DEFAULT_TEMPLATE = 'default.html'


def index(request):
    try:
        current_site = get_current_site(request)
        db = domains.objects.get(domain=current_site)
        dbid = db.id
        get_visitor_count = db.visitor
        add = 1
        total = get_visitor_count + add
        domains.objects.filter(pk=dbid).update(visitor=total)


    except:
        current_site = get_current_site(request)
        time = datetime.datetime.now()
        return render(request, 'parking.html', {'domain': current_site, 'time': time})

    else:
        asp = str(dbid) + '/' + 'index.html'
        template = loader.select_template((asp, DEFAULT_TEMPLATE))

        return HttpResponse(template.render())



from django.contrib.auth.models import User
from django.db import models

# Create your models here.
from django.urls import reverse


class domains(models.Model):
    user = models.ForeignKey(User, on_delete=models.CASCADE)
    domain = models.CharField(max_length=100, unique=True)
    publish_date = models.DateField(auto_now_add=True)
    visitor = models.IntegerField(default=1)

    def __str__(self):
        return self.domain

    class Meta:
        verbose_name = 'Domain'
        verbose_name_plural = 'Custom Domain'

    def get_absolute_url(self):
        return "http://%s" % (self.domain,)



class pages(models.Model):
    domain = models.ForeignKey(domains, on_delete=models.CASCADE)
    title = models.CharField(max_length=50)
    slug = models.SlugField()
    body = models.TextField()
    visitor = models.IntegerField(default=0)
    publish_date = models.DateField(auto_now_add=True)

    class Meta:
        verbose_name = 'Pages'
        verbose_name_plural = 'Pages'

    def __str__(self):
        return self.domain.domain




from django.contrib import admin

# Register your models here.
from bigsansar.contrib.sites.forms import create_domainform
from bigsansar.contrib.sites.models import domains, pages


class domainadmin(admin.ModelAdmin):
    form = create_domainform
    list_display = ['domain', 'publish_date', 'visitor']


class pageadmin(admin.ModelAdmin):
    pass


admin.site.register(domains, domainadmin)
admin.site.register(pages, pageadmin)